# KneadData #

----

* For complete documentation, please see the [KneadData User Manual](https://bitbucket.org/biobakery/kneaddata).

* Please direct questions to the [KneadData Google Group](https://groups.google.com/d/forum/kneaddata-users).

* If you use the KneadData software, please cite our manuscript: TDB

----

KneadData is a tool designed to perform quality control on metagenomic sequencing data, especially data from microbiome experiments. In these experiments, samples are typically taken from a host in hopes of learning something about the microbial community on the host. However, metagenomic sequencing data from such experiments will often contain a high ratio of host to bacterial reads. This tool aims to perform principled in silico separation of bacterial reads from these "contaminant" reads, be they from the host, from bacterial 16S sequences, or other user-defined sources.

